@@ -36,26 +36,23 @@ output
 
 # Main function  
 
-  output.list <- lapply(actionId, FUN= function (b) {
+output.list <- lapply(actionId, FUN= function (b) {
     
       Votes.getBillAction.basic(.actionId=b)
-           
-        
+              
     }
   )
 
-# which list entry has the most columns, how many are these?
-coln <- which.is.max(sapply(output.list, ncol));
-max.cols <- max(sapply(output.list, ncol));
-
-# give all list entries (dfs in list) the same number of columns and the same names
-output.list2 <- lapply(output.list, function(x){
-if (ncol(x) < max.cols) x <- data.frame(cbind(matrix(NA, ncol=max.cols-ncol(x), nrow = 1, ),x),row.names=NULL)
-names(x) <- names(output.list[[coln]])
-x
+output.list2 <- lapply(output.list, FUN=function (x){
+  
+  varnames <- names(x) 
+  varnames.clean <- gsub(pattern=".text", replacement="", x=varnames, fixed=TRUE)
+  names(x) <- varnames.clean
+  x
+  
 })
 
-output <- do.call("rbind",output.list2)
+output <- dfList(redlist(output.list2))
 output
 
 
